@@ -11,7 +11,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.0304';
+our $VERSION = '0.0305';
 
 use Plack::Runner;
 
@@ -115,6 +115,21 @@ Specifies the path to SSL key file. (default: none)
 
 Specifies the path to SSL certificate file. (default: none)
 
+=head2 --ssl-ca-file
+
+Specifies the path to SSL CA certificate file which will be a part of server's
+certificate chain. (default: none)
+
+=head2 --ssl-client-ca-file
+
+Specifies the path to SSL CA certificate file for client verification.
+(default: none)
+
+=head2 --ssl-verify-mode
+
+Specifies the verification mode for the client certificate.
+See L<IO::Socket::SSL/SSL_verify_mode> for details. (default: 0)
+
 =head2 --ipv6
 
 Enables IPv6 support. The L<IO::Socket::IP> module is required. (default: 0)
@@ -241,7 +256,7 @@ Paul Seamons <paul@seamons.com>
 
 =head1 LICENSE
 
-Copyright (c) 2013-2016 Piotr Roszatycki <dexter@cpan.org>.
+Copyright (c) 2013-2017 Piotr Roszatycki <dexter@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as perl itself.
